@@ -2,14 +2,14 @@
 #'
 #' @title Inverse Distance Weighting with custom distances
 #' @description This function takes a rasterstack of pathdistances and generates surfaces by weighting parameter values by these distances
-#' @param spdf SpatialPointsDataFrame object
+#' @param sf_ob sf object with point geometries
 #' @param rstack RasterStack of path distances
 #' @param paramlist character. String representing parameter names
 #' @param overlapped logical. Default is FALSE, specify TRUE if some points lie on top of barriers
-#' @param yearmon character. String specifying the name of the spdf
+#' @param yearmon character. String specifying the name of the sf object
 #' @param removefile logical. Remove files after processing?
 #' @param dist_power numeric. Distance decay power (p)
-#' @param trim_rstack logical. Trim the raster stack by the convex hull of spdf
+#' @param trim_rstack logical. Trim the raster stack by the convex hull of sf_ob
 #'
 #' @details Under the hood, this function evaluates:
 #' \deqn{V = \frac{\sum\limits_{i=1}^n v_i \frac{1}{d_i^p}}{\sum\limits_{i=1}^n \frac{1}{d_i^p}}}
@@ -19,14 +19,16 @@
 #' @return RasterLayer
 #'
 #' @importFrom raster calc reclassify writeRaster stack rasterize cover
-#' @importFrom rgeos gConvexHull
 #' @importFrom methods new slot
+#' @importFrom sf st_as_sf st_convex_hull
 #' @export
 #'
 #' @examples
-#' spdf <- data.frame(rnorm(2))
-#' xy   <- data.frame(x = c(4, 2), y = c(8, 4))
-#' coordinates(spdf) <- xy
+#' library(sf)
+#' sf_ob <- data.frame(rnorm(2))
+#' xy    <- data.frame(x = c(4, 2), y = c(8, 4))
+#' sf_ob <- st_as_sf(cbind(sf_ob, xy), coords = c("x", "y"))
+#'
 #' m <- matrix(NA, 10, 10)
 #' costras <- raster(m, xmn = 0, xmx = ncol(m), ymn = 0, ymx = nrow(m))
 #'
@@ -37,11 +39,11 @@
 #'   costras[, i] <- costras[, i] + i
 #' }
 #'
-#' rstack <- pathdistGen(spdf, costras, 100, progressbar = FALSE)
-#' final.raster <- ipdwInterp(spdf, rstack, paramlist = c("rnorm.2."), overlapped = TRUE)
+#' rstack <- pathdistGen(sf_ob, costras, 100, progressbar = FALSE)
+#' final.raster <- ipdwInterp(sf_ob, rstack, paramlist = c("rnorm.2."), overlapped = TRUE)
 #' plot(final.raster)
-#' plot(spdf, add = TRUE)
-ipdwInterp <- function(spdf, rstack, paramlist, overlapped = FALSE,
+#' plot(sf_ob, add = TRUE)
+ipdwInterp <- function(sf_ob, rstack, paramlist, overlapped = FALSE,
                        yearmon = "default", removefile = TRUE, dist_power = 1,
                        trim_rstack = FALSE) {
 
@@ -49,24 +51,24 @@ ipdwInterp <- function(spdf, rstack, paramlist, overlapped = FALSE,
     stop("Must pass a specific column name to the paramlist argument.")
   }
 
-  if (any(!(paramlist %in% names(spdf)))) {
+  if (any(!(paramlist %in% names(sf_ob)))) {
     stop(
       paste0("Variable(s) '",
-        paste0(paramlist[!(paramlist %in% names(spdf))],
-          collapse = "', '"), "' does not exist in spdf object."))
+        paste0(paramlist[!(paramlist %in% names(sf_ob))],
+          collapse = "', '"), "' does not exist in sf_ob object."))
   }
 
 
   range <- slot(rstack, "range")
 
   if (trim_rstack) {
-    rstack <- raster::mask(rstack, rgeos::gConvexHull(spdf), inverse = FALSE)
+    rstack <- raster::mask(rstack, sf::st_convex_hull(sf_ob), inverse = FALSE)
   }
 
   for (k in seq_len(length(paramlist))) {
     points_layers <- rm_na_pointslayers(param_name = paramlist[k],
-      spdf = spdf, rstack = rstack)
-    spdf   <- points_layers$spdf
+      sf_ob = sf_ob, rstack = rstack)
+    sf_ob   <- points_layers$sf_ob
     rstack <- points_layers$rstack
 
     # if(overlapped == TRUE){ #need to set na.rm = TRUE if points are on land?
@@ -79,7 +81,7 @@ ipdwInterp <- function(spdf, rstack, paramlist, overlapped = FALSE,
     for (i in 1:dim(rstack)[3]) {
       # add power in numerator of below line
       ras.weight   <- rstack[[i]]^dist_power / rstack.sum
-      param.value  <- data.frame(spdf[i, paramlist[k]])
+      param.value  <- data.frame(sf_ob[i, paramlist[k]])
       param.value2 <- as.vector(unlist(param.value[1]))
       ras.mult     <- ras.weight * param.value2
 
@@ -107,7 +109,7 @@ ipdwInterp <- function(spdf, rstack, paramlist, overlapped = FALSE,
       finalraster <- raster::reclassify(finalraster, cbind(0, NA))
     }
 
-    r           <- raster::rasterize(spdf, rstack[[1]], paramlist[k])
+    r           <- raster::rasterize(sf_ob, rstack[[1]], paramlist[k])
     finalraster <- raster::cover(r, finalraster)
     finalraster <- new("ipdwResult", finalraster,
       range = range,
@@ -128,24 +130,24 @@ ipdwInterp <- function(spdf, rstack, paramlist, overlapped = FALSE,
 
 #' @name rm_na_pointslayers
 #'
-#' @title Remove NA SpatialPointsDataFrame features and drop corresponding raster stack layers
-#' @description Remove NA SpatialPointsDataFrame features and drop corresponding raster stack layers
+#' @title Remove NA points features and drop corresponding raster stack layers
+#' @description Remove NA points features and drop corresponding raster stack layers
 #' @param param_name character name of data column
-#' @param spdf SpatialPointsDataFrame object
+#' @param sf_ob sf object with point geometries
 #' @param rstack RasterStack or RasterBrick
 #' @export
 
-rm_na_pointslayers <- function(param_name, spdf, rstack) {
-  param_index_x <- which(names(spdf) == param_name)
-  param_na_y    <- which(is.na(spdf@data[, param_index_x]))
+rm_na_pointslayers <- function(param_name, sf_ob, rstack) {
+  param_index_x <- which(names(sf_ob) == param_name)  
+  param_na_y    <- which(is.na(sf_ob[, param_index_x]))
 
   if (length(param_na_y) > 0) {
-    spdf   <- spdf[-which(is.na(spdf@data[, param_index_x])), ]
+    sf_ob   <- sf_ob[-which(is.na(sf_ob[, param_index_x])), ]
     rstack <- raster::dropLayer(rstack, param_na_y)
   }
-  list(spdf = spdf, rstack = rstack)
+  list(sf_ob = sf_ob, rstack = rstack)
 }
 
 ipdwResult <- setClass("ipdwResult",
   slots = c(range = "numeric", dist_power = "numeric"),
-  contains = "RasterLayer")
\ No newline at end of file
+  contains = "RasterLayer")
