@@ -3,10 +3,10 @@
 #' @title Generate a stack of path distance raster objects
 #' @description Generate a stack of path accumulated distance raster objects
 #'
-#' @param spdf SpatialPointsDataFrame object
+#' @param sf_ob sf object with point geometries
 #' @param costras RasterLayer cost raster
 #' @param range numeric. Range of interpolation neighborhood
-#' @param yearmon character. String specifying the name of the spdf
+#' @param yearmon character. String specifying the name of the sf_ob
 #' @param progressbar logical show progressbar during processing?
 #'
 #' @return RasterStack object of path distances
@@ -14,12 +14,14 @@
 #' @importFrom raster res reclassify writeRaster stack hist
 #' @importFrom gdistance transition accCost
 #' @importFrom utils setTxtProgressBar
+#' @importFrom sf st_coordinates
 #' @export
 #'
 #' @examples
-#' spdf <- data.frame(rnorm(2))
-#' xy <- data.frame(x = c(4, 2), y = c(8, 4))
-#' coordinates(spdf) <- xy
+#' library(sf)
+#' sf_ob <- data.frame(rnorm(2))
+#' xy   <- data.frame(x = c(4, 2), y = c(8, 4))
+#' sf_ob <- st_as_sf(cbind(sf_ob, xy), coords = c("x", "y"))
 #'
 #' m <- matrix(NA, 10, 10)
 #' costras <- raster(m, xmn = 0, xmx = ncol(m), ymn = 0, ymx = nrow(m))
@@ -30,17 +32,17 @@
 #'   costras[, i] <- costras[, i] + i
 #' }
 #'
-#' rstack <- pathdistGen(spdf, costras, 100, progressbar = FALSE)
-pathdistGen <- function(spdf, costras, range, yearmon = "default",
+#' rstack <- pathdistGen(sf_ob, costras, 100, progressbar = FALSE)
+pathdistGen <- function(sf_ob, costras, range, yearmon = "default",
                         progressbar = TRUE) {
 
-  if (!inherits(spdf, "SpatialPointsDataFrame")) {
-    stop("spdf object must be of class SpatialPointsDataFrame")
+  if (!inherits(sf_ob, "sf")) {
+    stop("sf_ob object must be of class sf")
   }
 
-  if (!identical(raster::projection(spdf), raster::projection(costras))) {
+  if (!identical(raster::projection(sf_ob), raster::projection(costras))) {
     stop("Point data projection and cost raster projections do not match,
-    		 see rgdal::spTransform")
+    		 see sf::st_transform")
   }
 
   ipdw_range <- range / raster::res(costras)[1] / 2 # this is a per cell distance
@@ -50,8 +52,8 @@ pathdistGen <- function(spdf, costras, range, yearmon = "default",
   trans <- gdistance::transition(costras, function(x) 1 / max(x),
     directions = 16)
   i <- 1
-  coord <- spdf[i, ]
-  costsurf <- gdistance::accCost(trans, coord)
+  coord <- sf_ob[i, ]
+  costsurf <- gdistance::accCost(trans, t(matrix(st_coordinates(coord))))
 
   ipdw_dist <- raster::hist(costsurf, plot = FALSE)$breaks[2]
   if (ipdw_dist < ipdw_range) {
@@ -59,13 +61,13 @@ pathdistGen <- function(spdf, costras, range, yearmon = "default",
   }
 
   if (progressbar == TRUE) {
-    pb <- utils::txtProgressBar(max = nrow(spdf),
+    pb <- utils::txtProgressBar(max = nrow(sf_ob),
       style = 3)
   }
 
-  for (i in seq_len(nrow(spdf))) {
-    coord <- spdf[i, ]
-    costsurf <- gdistance::accCost(trans, coord)
+  for (i in seq_len(nrow(sf_ob))) {
+    coord <- sf_ob[i, ]
+    costsurf <- gdistance::accCost(trans, t(matrix(st_coordinates(coord))))
     costsurf_reclass <- raster::reclassify(costsurf, c(ipdw_dist, +Inf, NA,
       ipdw_range, ipdw_dist, ipdw_range))
     # raster cells are 1 map unit
@@ -107,4 +109,4 @@ pathdistGen <- function(spdf, costras, range, yearmon = "default",
 }
 
 pathDist   <- setClass("pathDist",
-  slots = c(range = "numeric"), contains = "RasterBrick")
\ No newline at end of file
+  slots = c(range = "numeric"), contains = "RasterBrick")
